@@ -43,7 +43,8 @@ namespace Kasten2
 static const QStringList viewProfileFileNameFilter =
     QStringList() << QLatin1String( "*.obavp" ) << QLatin1String( "*.olock" );
 static const QString viewProfileFileSuffix = QLatin1String( ".obavp" );
-static const QString viewProfileSubDir = QLatin1String( "okteta/viewprofiles" );
+static const QString viewProfileDirSubPath = QLatin1String( "okteta/viewprofiles" );
+static const QString defaultViewProfileFileSubPath = QLatin1String( "okteta/defaultviewprofile" );
 static const int DefaultNoOfBytesPerLine = 16;
 static const int DefaultNoOfBytesPerGroup = 4;
 static const int DefaultLayoutStyle = 0;
@@ -110,10 +111,16 @@ updateLockStatus( ByteArrayViewProfileFileInfoLookup& viewProfileFileInfoLookup,
     }
 }
 
+static QString
+defaultViewProfileFilePath()
+{
+    return KGlobal::dirs()->saveLocation( "data" ) + defaultViewProfileFileSubPath;
+}
+
 static QString
 viewProfileFilePath( const ByteArrayViewProfile::Id& viewProfileId )
 {
-    return KGlobal::dirs()->saveLocation( "data", viewProfileSubDir ) + viewProfileId + viewProfileFileSuffix;
+    return KGlobal::dirs()->saveLocation( "data", viewProfileDirSubPath ) + viewProfileId + viewProfileFileSuffix;
 }
 
 static QString
@@ -137,7 +144,7 @@ ByteArrayViewProfileManager::ByteArrayViewProfileManager()
 
     foreach( const QString& dataFolderPath, dataFolderPaths )
     {
-        const QString viewProfileFolderPath = dataFolderPath + viewProfileSubDir;
+        const QString viewProfileFolderPath = dataFolderPath + viewProfileDirSubPath;
         // watch folder for changes
         mViewProfileFileWatcher->addDir( viewProfileFolderPath, KDirWatch::WatchDirOnly );
 kDebug() << "adding Dir"<<viewProfileFolderPath;
@@ -146,9 +153,19 @@ kDebug() << "adding Dir"<<viewProfileFolderPath;
         onViewProfilesFolderChanged( viewProfileFolderPath );
     }
 
-    // tmp
-    if( ! mViewProfiles.isEmpty() )
-        mDefaultViewProfileId = mViewProfiles.at(0).id();
+    // default view profile
+    // While there is no proper config syncing offer in the used frameworks, use a
+    // single file with the id as content as workaround and watch for it changing
+    KDirWatch* defaultViewProfileWatcher = new KDirWatch( this );
+    connect( defaultViewProfileWatcher, SIGNAL(created(QString)),
+             SLOT(onDefaultViewProfileChanged(QString)) );
+    connect( defaultViewProfileWatcher, SIGNAL(dirty(QString)),
+             SLOT(onDefaultViewProfileChanged(QString)) );
+    const QString _defaultViewProfileFilePath = defaultViewProfileFilePath();
+
+    defaultViewProfileWatcher->addFile( _defaultViewProfileFilePath );
+
+    onDefaultViewProfileChanged( _defaultViewProfileFilePath );
 
     // report any problems with existing view profiles?
 }
@@ -264,25 +281,11 @@ ByteArrayViewProfileManager::removeViewProfiles( const QList<ByteArrayViewProfil
 void
 ByteArrayViewProfileManager::setDefaultViewProfile( const ByteArrayViewProfile::Id& viewProfileId )
 {
-    // no change?
-    if( mDefaultViewProfileId == viewProfileId )
-        return;
+    QFile defaultViewProfileFile( defaultViewProfileFilePath() );
+    defaultViewProfileFile.open( QIODevice::WriteOnly );
 
-    bool isExisting = false;
-    foreach( const ByteArrayViewProfile& viewProfile, mViewProfiles )
-    {
-        if( viewProfile.id() == viewProfileId )
-        {
-            isExisting = true;
-            break;
-        }
-    }
-
-    if( isExisting )
-    {
-        mDefaultViewProfileId = viewProfileId;
-        emit defaultViewProfileChanged( mDefaultViewProfileId );
-    }
+    defaultViewProfileFile.write( viewProfileId.toUtf8() );
+    defaultViewProfileFile.close();
 }
 
 ByteArrayViewProfileLock
@@ -331,7 +334,15 @@ kDebug() << "Loading" << QFileInfo(absoluteFilePath).baseName() << absoluteFileP
     ByteArrayViewProfile result;
 
     KConfig configFile( absoluteFilePath, KConfig::SimpleConfig );
-    // TODO: version check
+
+    // check version
+    KConfigGroup formatConfigGroup = configFile.group( "OBAVP" );
+    const QString formatVersion = formatConfigGroup.readEntry( "Version" );
+    if( ! formatVersion.startsWith(QLatin1String( "1." )) )
+    {
+kDebug() << "ViewProfile file has an unsupported version:" << formatVersion;
+        return result;
+    }
 
     result.setId( QFileInfo(absoluteFilePath).baseName() );
 
@@ -370,6 +381,9 @@ kDebug() << "------------------ Saving"<<viewProfile.id();
     const QString fileName = viewProfileFilePath( viewProfile.id() );
     KConfig configFile( fileName, KConfig::SimpleConfig );
 
+    KConfigGroup formatConfigGroup = configFile.group( "OBAVP" );
+    formatConfigGroup.writeEntry( "Version", "1.0" );
+
     KConfigGroup generalConfigGroup = configFile.group( "General" );
     generalConfigGroup.writeEntry( "Title", viewProfile.viewProfileTitle() );
 
@@ -470,12 +484,18 @@ kDebug() << "locked profiles:" << newUnlockedViewProfileIds;
             continue;
 
        // all other files assumed to be viewProfile files
-       // TODO: check validness
-        const QDateTime fileInfoLastModified = viewProfileFileInfo.lastModified();
         const ByteArrayViewProfile::Id viewProfileId = viewProfileFileInfo.baseName();
-        ByteArrayViewProfileFileInfoLookup::Iterator infoIt =
+kDebug() <<"going to load"<<viewProfileId;
+        // load file
+        const ByteArrayViewProfile viewProfile = loadViewProfile( viewProfileFileInfo.absoluteFilePath() );
+        // loading failed? Treat as not existing
+        if( viewProfile.id().isEmpty() )
+            continue;
+
+        const ByteArrayViewProfileFileInfoLookup::Iterator infoIt =
             viewProfileFileInfoLookup.find( viewProfileId );
         const bool isKnown = ( infoIt != viewProfileFileInfoLookup.end() );
+        const QDateTime fileInfoLastModified = viewProfileFileInfo.lastModified();
         // is known?
         if( isKnown )
         {
@@ -494,10 +514,6 @@ kDebug() << "locked profiles:" << newUnlockedViewProfileIds;
             viewProfileFileInfoLookup.insert( viewProfileId, info );
         }
 
-kDebug() <<"going to load"<<viewProfileId;
-        // load file
-        // TODO: check validness
-        const ByteArrayViewProfile viewProfile = loadViewProfile( viewProfileFileInfo.absoluteFilePath() );
         if( isKnown )
         {
             QList<ByteArrayViewProfile>::Iterator it = mViewProfiles.begin();
@@ -566,6 +582,42 @@ kDebug() << "locked profiles" << newLockedViewProfileIds;
         emit defaultViewProfileChanged( mDefaultViewProfileId );
 }
 
+void ByteArrayViewProfileManager::onDefaultViewProfileChanged( const QString& path )
+{
+    QFile defaultViewProfileFile( path );
+    defaultViewProfileFile.open( QIODevice::ReadOnly );
+
+    const QByteArray fileContent = defaultViewProfileFile.readAll();
+    const QString viewProfileId = QString::fromUtf8( fileContent, fileContent.size() );
+    defaultViewProfileFile.close();
+
+kDebug() << "Default viewprofile read:" << viewProfileId;
+
+    // no id set?
+    if( viewProfileId.isEmpty() )
+        return;
+
+    // no change?
+    if( mDefaultViewProfileId == viewProfileId )
+        return;
+
+    bool isExisting = false;
+    foreach( const ByteArrayViewProfile& viewProfile, mViewProfiles )
+    {
+        if( viewProfile.id() == viewProfileId )
+        {
+            isExisting = true;
+            break;
+        }
+    }
+
+    if( isExisting )
+    {
+        mDefaultViewProfileId = viewProfileId;
+        emit defaultViewProfileChanged( mDefaultViewProfileId );
+    }
+}
+
 
 ByteArrayViewProfileManager::~ByteArrayViewProfileManager()
 {
