@@ -17,6 +17,7 @@
 #include "uml.h"
 #include "umldoc.h"
 #include "umlscene.h"
+#include "umlview.h"
 #include "umlobject.h"
 #include "folder.h"
 #include "classifier.h"
@@ -153,7 +154,7 @@ void UMLDragData::setUMLDataClip2(UMLObjectList& objects, UMLListViewItemList& u
     xmiclip.appendChild(viewsTag);
 
     foreach( UMLView* view, diagrams ) {
-        view->saveToXMI(domDoc, viewsTag);
+        view->umlScene()->saveToXMI(domDoc, viewsTag);
     }
 
     QDomElement itemsTag = domDoc.createElement("umllistviewitems");
@@ -435,7 +436,7 @@ bool UMLDragData::decodeClip2(const QMimeData* mimeData, UMLObjectList& objects,
         }
         UMLFolder *f = static_cast<UMLFolder*>(po);
         UMLView* view = new UMLView(f);
-        view->loadFromXMI(diagramElement);
+        view->umlScene()->loadFromXMI(diagramElement);
         diagrams.append(view);
         diagramNode = diagramNode.nextSibling();
         diagramElement = diagramNode.toElement();
@@ -672,9 +673,10 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     }
 
     UMLView *view = UMLApp::app()->currentView();
+    UMLScene *scene = view->umlScene();
     while ( !widgetElement.isNull() ) {
 
-        UMLWidget* widget = view->loadWidgetFromXMI(widgetElement);
+        UMLWidget* widget = scene->loadWidgetFromXMI(widgetElement);
         if (widget)
             widgets.append(widget);
 
@@ -688,10 +690,9 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     QDomElement associationWidgetElement = associationWidgetNode.toElement();
     while ( !associationWidgetElement.isNull() ) {
         AssociationWidget* associationWidget = AssociationWidget::create(view->umlScene());
-        if (associationWidget->loadFromXMI(associationWidgetElement, widgets))
+        if (associationWidget->loadFromXMI(associationWidgetElement, widgets, 0))
             associations.append(associationWidget);
         else {
-            //associationWidget->cleanup();
             delete associationWidget;
         }
         associationWidgetNode = associationWidgetNode.nextSibling();
