@@ -36,19 +36,18 @@ namespace Uml
     // Create the UMLObject
     void CmdCreateUMLObject::redo()
     {
-        UMLDoc *doc = UMLApp::app()->document();
-
         // This object was removed from it's package when it was deleted
         // so add it back to it's package ( if it belonged to one )
         UMLPackage *pkg = m_obj->umlPackage();
-        if (pkg == NULL) {
-          // object does not belong to any package
+        if (pkg) {
+            // add this object to its parent package
+            pkg->addObject(m_obj);
 
         } else {
-          // add this object to its parent package
-          pkg->addObject(m_obj);
+            // object does not belong to any package
         }
 
+        UMLDoc *doc = UMLApp::app()->document();
         doc->signalUMLObjectCreated(m_obj);
     }
 
