@@ -26,7 +26,7 @@
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlview.h"
-#include "umlwidgetcolorpage.h"
+#include "umlwidgetstylepage.h"
 
 // kde includes
 #include <klocale.h>
@@ -45,7 +45,7 @@
  *  @param assoc     Determines whether to display associations
  */
 ClassPropDlg::ClassPropDlg(QWidget *parent, UMLObject * c, bool assoc)
-  : KPageDialog(parent)
+  : DialogBase(parent)
 {
     init();
     m_pWidget = 0;
@@ -65,7 +65,7 @@ ClassPropDlg::ClassPropDlg(QWidget *parent, UMLObject * c, bool assoc)
  *  @param  o       The ObjectWidget to display properties of.
  */
 ClassPropDlg::ClassPropDlg(QWidget *parent, ObjectWidget *o)
-  : KPageDialog(parent)
+  : DialogBase(parent)
 {
     init();
     m_pWidget = o;
@@ -74,7 +74,7 @@ ClassPropDlg::ClassPropDlg(QWidget *parent, ObjectWidget *o)
     m_doc = UMLApp::app()->document();
 
     setupGeneralPage();
-    setupColorPage();
+    setupStylePage();
     setupFontPage();
 
     setMinimumSize(340,420);
@@ -89,7 +89,7 @@ ClassPropDlg::ClassPropDlg(QWidget *parent, ObjectWidget *o)
  *  @param  o       The UMLWidget to display properties of.
  */
 ClassPropDlg::ClassPropDlg(QWidget *parent, UMLWidget *w)
-  : KPageDialog(parent)
+  : DialogBase(parent)
 {
     init();
     m_pWidget = w;
@@ -117,7 +117,7 @@ ClassPropDlg::ClassPropDlg(QWidget *parent, UMLWidget *w)
         w->baseType() == WidgetBase::wt_Interface) {
         setupDisplayPage();
     }
-    setupColorPage();
+    setupStylePage();
     setupFontPage();
     connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
     connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
@@ -139,7 +139,7 @@ void ClassPropDlg::init()
     m_pEntityAttributePage = 0;
     m_pEntityConstraintPage = 0;
     m_pOptionsPage = 0;
-    m_pColorPage = 0;
+    m_pStylePage = 0;
     m_doc = UMLApp::app()->document();
 }
 
@@ -188,8 +188,8 @@ void ClassPropDlg::slotApply()
     if (m_pOptionsPage) {
         m_pOptionsPage->updateUMLWidget();
     }
-    if (m_pColorPage) {
-        m_pColorPage->updateUMLWidget();
+    if (m_pStylePage) {
+        m_pStylePage->updateUMLWidget();
     }
     if (m_pWidget) {
         m_pWidget->setFont( m_pChooser->font() );
@@ -203,7 +203,10 @@ void ClassPropDlg::setupPages(bool assoc)
 {
     setupGeneralPage();
 
-    UMLObject::ObjectType ot = m_pObject->baseType();
+    UMLObject::ObjectType ot = UMLObject::ot_UMLObject;
+    if (m_pObject) {
+        ot = m_pObject->baseType();
+    }
     // add extra pages for class
     if (ot == UMLObject::ot_Class ) {
         setupAttributesPage();
@@ -231,16 +234,6 @@ void ClassPropDlg::setupPages(bool assoc)
     }
 }
 
-QFrame* ClassPropDlg::createPage(const QString& name, const QString& header, Icon_Utils::IconType icon)
-{
-    QFrame* page = new QFrame();
-    KPageWidgetItem *pageItem = new KPageWidgetItem( page, name );
-    pageItem->setHeader( header );
-    pageItem->setIcon( Icon_Utils::DesktopIcon(icon) );
-    addPage( pageItem );
-    return page;
-}
-
 /**
  * Sets up the page "General" for the component.
  */
@@ -257,13 +250,13 @@ void ClassPropDlg::setupGeneralPage()
 /**
  * Sets up the page "Style" for the component.
  */
-void ClassPropDlg::setupColorPage()
+void ClassPropDlg::setupStylePage()
 {
-    QFrame * page = createPage( i18nc("widget color page name", "Color"), i18n("Widget Colors"),
+    QFrame * page = createPage( i18nc("widget style page name", "Style"), i18n("Widget Style"),
                                 Icon_Utils::it_Properties_Color );
-    QHBoxLayout * m_pColorLayout = new QHBoxLayout(page);
-    m_pColorPage = new UMLWidgetColorPage(page, m_pWidget);
-    m_pColorLayout->addWidget(m_pColorPage);
+    QHBoxLayout * m_pStyleLayout = new QHBoxLayout(page);
+    m_pStylePage = new UMLWidgetStylePage(page, m_pWidget);
+    m_pStyleLayout->addWidget(m_pStylePage);
 }
 
 /**
@@ -370,7 +363,7 @@ void ClassPropDlg::setupAssociationsPage()
 {
     QFrame* page = createPage( i18n("Associations"), i18n("Class Associations"),
                                Icon_Utils::it_Properties_Associations );
-    m_pAssocPage = new AssocPage(page, UMLApp::app()->currentView(), m_pObject);
+    m_pAssocPage = new AssocPage(page, UMLApp::app()->currentView()->umlScene(), m_pObject);
     QHBoxLayout* assocLayout = new QHBoxLayout(page);
     assocLayout->addWidget(m_pAssocPage);
 }
