@@ -1,20 +1,11 @@
-
 /***************************************************************************
-                          codegenerationpolicypage.cpp  -  description
-                             -------------------
-    begin                : Tue Jul 29 2003
-    copyright            : (C) 2003 by Brian Thomas
-    email                : brian.thomas@gsfc.nasa.gov
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2007                                               *
+ *   copyright (C) 2003      Brian Thomas <brian.thomas@gsfc.nasa.gov>     *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -22,21 +13,23 @@
 #include "defaultcodegenpolicypage.h"
 
 // qt/kde includes
-#include <QLabel>
+#include <QtGui/QLabel>
 #include <klocale.h>
 
-
-/** This is the page which comes up IF there is no special options for the
+/**
+ * This is the page which comes up IF there is no special options for the
  * code generator.
  */
-DefaultCodeGenPolicyPage::DefaultCodeGenPolicyPage ( QWidget *parent, const char *name, CodeGenPolicyExt * policy )
+DefaultCodeGenPolicyPage::DefaultCodeGenPolicyPage(QWidget *parent, const char *name, CodeGenPolicyExt * policy)
         :CodeGenerationPolicyPage(parent,name,policy)
 {
-    textLabel = new QLabel(this);
-    textLabel->setObjectName("textLabel");
-    textLabel->setText(tr2i18n("<p align=\"center\">No Options Available.</p>"));
+    m_textLabel = new QLabel(this);
+    m_textLabel->setObjectName("textLabel");
+    m_textLabel->setText(tr2i18n("<p align=\"center\">No Options Available.</p>"));
 }
 
-DefaultCodeGenPolicyPage::~DefaultCodeGenPolicyPage() { }
+DefaultCodeGenPolicyPage::~DefaultCodeGenPolicyPage()
+{
+}
 
 #include "defaultcodegenpolicypage.moc"
