@@ -12,6 +12,8 @@
 #include "umlviewimageexporter.h"
 
 // application specific includes
+#include "dotgenerator.h"
+#include "umlfiledialog.h"
 #include "umlviewimageexportermodel.h"
 #include "uml.h"
 #include "umldoc.h"
@@ -69,7 +71,8 @@ void UMLViewImageExporter::exportView()
 
     // export the view
     app->document()->writeToStatusBar(i18n("Exporting view..."));
-    QString error = UMLViewImageExporterModel().exportView(m_scene,
+    UMLViewImageExporterModel theExporter;
+    QString error = theExporter.exportView(m_scene,
                             UMLViewImageExporterModel::mimeTypeToImageType(m_imageMimeType), m_imageURL);
     if (!error.isNull()) {
         KMessageBox::error(app, i18n("An error happened when exporting the image:\n") + error);
@@ -125,7 +128,7 @@ bool UMLViewImageExporter::getParametersFromUser()
 
     // configure & show the file dialog
     KUrl url;
-    QPointer<KFileDialog> dialog = new KFileDialog(url, QString(), UMLApp::app());
+    QPointer<UMLFileDialog> dialog = new UMLFileDialog(url, QString(), UMLApp::app());
     prepareFileDialog(dialog);
     dialog->exec();
 
@@ -158,11 +161,15 @@ bool UMLViewImageExporter::getParametersFromUser()
  *
  * @param fileDialog The dialog to prepare.
  */
-void UMLViewImageExporter::prepareFileDialog(KFileDialog *fileDialog)
+void UMLViewImageExporter::prepareFileDialog(UMLFileDialog *fileDialog)
 {
     // get all supported mime types
     QStringList mimeTypes = UMLViewImageExporterModel::supportedMimeTypes();
 
+    QHash<QString,QString> configFiles;
+    if (!DotGenerator::availableConfigFiles(m_scene, configFiles) || configFiles.size() == 0)
+        mimeTypes.removeOne("image/x-dot");
+
     fileDialog->setCaption(i18n("Save As"));
     fileDialog->setOperationMode(KFileDialog::Saving);
     fileDialog->setMimeFilter(mimeTypes, m_imageMimeType);
