@@ -19,7 +19,7 @@
 /**
  * Constructs a ArtifactWidget.
  *
- * @param scene              The parent of this ArtifactWidget.
+ * @param scene     The parent of this ArtifactWidget.
  * @param a         The Artifact this widget will be representing.
  */
 ArtifactWidget::ArtifactWidget(UMLScene *scene, UMLArtifact *a)
@@ -45,28 +45,32 @@ void ArtifactWidget::paint(QPainter& p, int offsetX, int offsetY)
     if ( UMLWidget::useFillColor() ) {
         p.setBrush( UMLWidget::fillColor() );
     } else {
-        p.setBrush( m_scene->viewport()->palette().color(QPalette::Background) );
+        p.setBrush( m_scene->view()->viewport()->palette().color(QPalette::Background) );
     }
 
-    UMLArtifact *umlart = static_cast<UMLArtifact*>(m_pObject);
-    UMLArtifact::Draw_Type drawType = umlart->getDrawAsType();
-    switch (drawType) {
-    case UMLArtifact::defaultDraw:
-        return drawAsNormal(p, offsetX, offsetY);
-        break;
-    case UMLArtifact::file:
-        return drawAsFile(p, offsetX, offsetY);
-        break;
-    case UMLArtifact::library:
-        return drawAsLibrary(p, offsetX, offsetY);
-        break;
-    case UMLArtifact::table:
-        return drawAsTable(p, offsetX, offsetY);
-        break;
-
-    default:
-        uWarning() << "Artifact drawn as unknown type";
-        break;
+    if (umlObject()) {
+        UMLArtifact *umlart = static_cast<UMLArtifact*>(m_pObject);
+        UMLArtifact::Draw_Type drawType = umlart->getDrawAsType();
+        switch (drawType) {
+        case UMLArtifact::defaultDraw:
+            drawAsNormal(p, offsetX, offsetY);
+            break;
+        case UMLArtifact::file:
+            drawAsFile(p, offsetX, offsetY);
+            break;
+        case UMLArtifact::library:
+            drawAsLibrary(p, offsetX, offsetY);
+            break;
+        case UMLArtifact::table:
+            drawAsTable(p, offsetX, offsetY);
+            break;
+        default:
+            uWarning() << "Artifact drawn as unknown type";
+            break;
+        }
+    }
+    else {
+        uWarning() << "Cannot draw as there is no UMLArtifact for this widget.";
     }
 }
 
@@ -161,7 +165,7 @@ void ArtifactWidget::drawAsFile(QPainter& p, int offsetX, int offsetY)
     p.drawLine(startX + 40, offsetY + 10, startX + 50, offsetY + 10);
     p.drawLine(startX + 40, offsetY, startX + 50, offsetY + 10);
 
-    p.setPen( QPen(Qt::black) );
+    p.setPen(textColor());
     p.setFont(font);
 
     p.drawText(offsetX, offsetY + h - fontHeight,
@@ -198,7 +202,7 @@ void ArtifactWidget::drawAsLibrary(QPainter& p, int offsetX, int offsetY)
     p.drawLine(startX + 40, offsetY + 10, startX + 50, offsetY + 10);
     p.drawLine(startX + 40, offsetY, startX + 50, offsetY + 10);
 
-    p.setPen( QPen(Qt::black) );
+    p.setPen(textColor());
     p.setFont(font);
 
     p.drawText(offsetX, offsetY + h - fontHeight,
@@ -237,7 +241,7 @@ void ArtifactWidget::drawAsTable(QPainter& p, int offsetX, int offsetY)
     p.drawLine(startX + 10, offsetY, startX + 10, offsetY + iconHeight);
     p.drawLine(startX, offsetY + (iconHeight/4), startX + 50, offsetY + (iconHeight/4));
 
-    p.setPen( QPen(Qt::black) );
+    p.setPen(textColor());
     p.setFont(font);
 
     p.drawText(offsetX, offsetY + h - fontHeight,
@@ -263,7 +267,7 @@ void ArtifactWidget::drawAsNormal(QPainter& p, int offsetX, int offsetY)
 
     p.drawRect(offsetX, offsetY, w, h);
 
-    p.setPen( QPen(Qt::black) );
+    p.setPen(textColor());
     p.setFont(font);
 
     if (!stereotype.isEmpty()) {
