@@ -11,29 +11,27 @@
 // onw header
 #include "messagewidget.h"
 
+//app includes
+#include "classifier.h"
+#include "debug_utils.h"
+#include "floatingtextwidget.h"
+#include "messagewidgetcontroller.h"
+#include "listpopupmenu.h"
+#include "objectwidget.h"
+#include "operation.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "umlview.h"
+#include "uniqueid.h"
+
 //qt includes
-#include <QMouseEvent>
 #include <QPolygon>
 #include <QMoveEvent>
 #include <QResizeEvent>
 #include <QtGui/QPainter>
-//kde includes
-#include <kcursor.h>
-#include <kmessagebox.h>
-#include <klocale.h>
 
-//app includes
-#include "classifier.h"
-#include "debug_utils.h"
-#include "messagewidgetcontroller.h"
-#include "floatingtextwidget.h"
-#include "objectwidget.h"
-#include "operation.h"
-#include "umlview.h"
-#include "umldoc.h"
-#include "uml.h"
-#include "uniqueid.h"
-#include "listpopupmenu.h"
+//kde includes
+#include <klocale.h>
 
 /**
  * Constructs a MessageWidget.
@@ -57,7 +55,7 @@ MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, ObjectWidget* b,
     m_nY = y;
     m_sequenceMessageType = sequenceMessageType;
     if (m_sequenceMessageType == Uml::sequence_message_creation) {
-        y -= m_pOw[Uml::B]->getHeight() / 2;
+        y -= m_pOw[Uml::B]->height() / 2;
         m_pOw[Uml::B]->setY(y);
     }
     updateResizability();
@@ -140,6 +138,10 @@ MessageWidget::~MessageWidget()
 {
 }
 
+/**
+ * Update the UMLWidget::m_resizable flag according to the
+ * charactersitics of this message.
+ */
 void MessageWidget::updateResizability()
 {
     if (m_sequenceMessageType == Uml::sequence_message_synchronous ||
@@ -149,6 +151,9 @@ void MessageWidget::updateResizability()
         UMLWidget::m_resizable = false;
 }
 
+/**
+ * Calls drawSynchronous() or drawAsynchronous().
+ */
 void MessageWidget::paint(QPainter& p, int offsetX, int offsetY)
 {
     if(!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
@@ -170,6 +175,10 @@ void MessageWidget::paint(QPainter& p, int offsetX, int offsetY)
     }
 }
 
+/**
+ * Draw a solid (triangular) arrowhead pointing in the given direction.
+ * The direction can be either Qt::LeftArrow or Qt::RightArrow.
+ */
 void MessageWidget::drawSolidArrowhead(QPainter& p, int x, int y, Qt::ArrowType direction)
 {
     int arrowheadExtentX = 4;
@@ -182,6 +191,12 @@ void MessageWidget::drawSolidArrowhead(QPainter& p, int x, int y, Qt::ArrowType
     p.drawPolygon(points);
 }
 
+/**
+ * Draw an arrow pointing in the given direction.
+ * The arrow head is not solid, i.e. it is made up of two lines
+ * like so:  --->
+ * The direction can be either Qt::LeftArrow or Qt::RightArrow.
+ */
 void MessageWidget::drawArrow(QPainter& p, int x, int y, int w,
                               Qt::ArrowType direction, bool useDottedLine /* = false */)
 {
@@ -204,14 +219,19 @@ void MessageWidget::drawArrow(QPainter& p, int x, int y, int w,
     p.drawLine(x, y, x + w, y);
 }
 
+/**
+ * Draws the calling arrow with filled in arrowhead, the
+ * timeline box and the returning arrow with a dashed line and
+ * stick arrowhead.
+ */
 void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w = getWidth() - 1;
-    int h = getHeight();
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w = width() - 1;
+    int h = height();
 
-    bool messageOverlaps = m_pOw[Uml::A] -> messageOverlap( getY(), this );
+    bool messageOverlaps = m_pOw[Uml::A] -> messageOverlap( y(), this );
 
     if(m_pOw[Uml::A] == m_pOw[Uml::B]) {
         p.fillRect( offsetX, offsetY, 17, h,  QBrush(Qt::white) );              //box
@@ -260,14 +280,17 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
     }
 }
 
+/**
+ * Draws a solid arrow line and a stick arrow head.
+ */
 void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w = getWidth() - 1;
-    int h = getHeight() - 1;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( getY(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( getY(), this );
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w = width() - 1;
+    int h = height() - 1;
+    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
 
     if(m_pOw[Uml::A] == m_pOw[Uml::B]) {
         if (messageOverlapsA)  {
@@ -304,14 +327,19 @@ void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
         drawSelected(&p, offsetX, offsetY);
 }
 
+/**
+ * Draws a solid arrow line and a stick arrow head to the
+ * edge of the target object widget instead of to the
+ * sequence line.
+ */
 void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w = getWidth() - 1;
-    //int h = getHeight() - 1;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( getY(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( getY(), this );
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w = width() - 1;
+    //int h = height() - 1;
+    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
 
     const int lineY = offsetY + 4;
     if (x1 < x2) {
@@ -335,18 +363,22 @@ void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
 }
 
 
+/**
+ * Draws a solid arrow line and a stick arrow head
+ * and a circle
+ */
 void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->getX();
+    int x1 = m_pOw[Uml::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
+    int w1 = m_pOw[Uml::A]->width() / 2;
     x1 += w1;
 
-    int w = getWidth() ;
+    int w = width() ;
 
     int h = 10;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( getY(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( getY(), this );
+    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
 
     if(x1 < x2) {
         if (messageOverlapsA)  {
@@ -373,15 +405,18 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
         drawSelected(&p, offsetX, offsetY);
 }
 
+/**
+ * Draws a circle and a solid arrow line and a stick arrow head.
+ */
 void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->getX();
+    int x1 = m_pOw[Uml::A]->x();
     int x2 = xclicked;
-    int w = getWidth() ;
+    int w = width() ;
 
     int h = 10;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( getY(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( getY(), this );
+    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
 
     if(x1 < x2) {
         if (messageOverlapsA)  {
@@ -410,6 +445,16 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
 
 }
 
+/**
+ * Overrides operation from UMLWidget.
+ *
+ * @param p Point to be checked.
+ *
+ * @return Non-zero if the point is on a part of the MessageWidget.
+ *         NB In case of a synchronous message, the empty space
+ *         between call line and return line does not count, i.e. if
+ *         the point is located in that space the function returns 0.
+ */
 int MessageWidget::onWidget(const QPoint & p)
 {
     if (m_sequenceMessageType != Uml::sequence_message_synchronous) {
@@ -417,15 +462,15 @@ int MessageWidget::onWidget(const QPoint & p)
     }
     // Synchronous message:
     // Consists of top arrow (call) and bottom arrow (return.)
-    if (p.x() < getX() || p.x() > getX() + getWidth())
+    if (p.x() < x() || p.x() > x() + width())
         return 0;
     const int tolerance = 5;  // pixels
     const int pY = p.y();
-    const int topArrowY = getY() + 3;
-    const int bottomArrowY = getY() + getHeight() - 3;
+    const int topArrowY = y() + 3;
+    const int bottomArrowY = y() + height() - 3;
     if (pY < topArrowY - tolerance || pY > bottomArrowY + tolerance)
         return 0;
-    if (getHeight() <= 2 * tolerance)
+    if (height() <= 2 * tolerance)
         return 1;
     if (pY > topArrowY + tolerance && pY < bottomArrowY - tolerance)
         return 0;
@@ -445,25 +490,29 @@ void MessageWidget::setTextPosition()
         return;
     }
     m_pFText->updateComponentSize();
-    int ftX = constrainX(m_pFText->getX(), m_pFText->getWidth(), m_pFText->textRole());
-    int ftY = getY() - m_pFText->getHeight();
+    int ftX = constrainX(m_pFText->x(), m_pFText->width(), m_pFText->textRole());
+    int ftY = y() - m_pFText->height();
     m_pFText->setX( ftX );
     m_pFText->setY( ftY );
 }
 
+/**
+ * Returns the textX arg with constraints applied.
+ * Auxiliary to setTextPosition() and constrainTextPos().
+ */
 int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
 {
     int result = textX;
-    const int minTextX = getX() + 5;
+    const int minTextX = x() + 5;
     if (textX < minTextX || tr == Uml::TextRole::Seq_Message_Self) {
         result = minTextX;
     } else {
         ObjectWidget *objectAtRight = NULL;
-        if (m_pOw[Uml::B]->getX() > m_pOw[Uml::A]->getX())
+        if (m_pOw[Uml::B]->x() > m_pOw[Uml::A]->x())
             objectAtRight = m_pOw[Uml::B];
         else
             objectAtRight = m_pOw[Uml::A];
-        const int objRight_seqLineX = objectAtRight->getX() + objectAtRight->getWidth() / 2;
+        const int objRight_seqLineX = objectAtRight->x() + objectAtRight->width() / 2;
         const int maxTextX = objRight_seqLineX - textWidth - 5;
         if (maxTextX <= minTextX)
             result = minTextX;
@@ -477,11 +526,11 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
  * Constrains the FloatingTextWidget X and Y values supplied.
  * Overrides operation from LinkWidget.
  *
- * @param textX             Candidate X value (may be modified by the constraint.)
- * @param textY             Candidate Y value (may be modified by the constraint.)
- * @param textWidth Width of the text.
- * @param textHeight        Height of the text.
- * @param tr                Uml::Text_Role of the text.
+ * @param textX        candidate X value (may be modified by the constraint)
+ * @param textY        candidate Y value (may be modified by the constraint)
+ * @param textWidth    width of the text
+ * @param textHeight   height of the text
+ * @param tr           Uml::TextRole of the text
  */
 void MessageWidget::constrainTextPos(int &textX, int &textY, int textWidth, int textHeight,
                                      Uml::TextRole tr)
@@ -497,12 +546,16 @@ void MessageWidget::constrainTextPos(int &textX, int &textY, int textWidth, int
 //     setY( textY + textHeight );   // NB: side effect
 }
 
+/**
+ * Shortcut for calling m_pFText->setLink() followed by
+ * this->setTextPosition().
+ */
 void MessageWidget::setLinkAndTextPos()
 {
-    if (m_pFText == NULL)
-        return;
-    m_pFText->setLink(this);
-    setTextPosition();
+    if (m_pFText) {
+        m_pFText->setLink(this);
+        setTextPosition();
+    }
 }
 
 void MessageWidget::moveEvent(QMoveEvent* /*m*/)
@@ -512,7 +565,7 @@ void MessageWidget::moveEvent(QMoveEvent* /*m*/)
         return;
     }
     //TODO why this condition?
-/*    if (m_scene->getSelectCount() > 2) {
+/*    if (m_scene->selectedCount() > 2) {
         return;
     }*/
 
@@ -525,6 +578,9 @@ void MessageWidget::resizeEvent(QResizeEvent* /*re*/)
 {
 }
 
+/**
+ * Calculate the geometry of the widget.
+ */
 void MessageWidget::calculateWidget()
 {
     setMessageText(m_pFText);
@@ -545,7 +601,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
             << ", idB=" << ID2STR(idB);
         return;
     }
-    m_nY = getY();
+    m_nY = y();
     if (m_nY < getMinY())
         m_nY = getMinY();
     if (m_nY > getMaxY())
@@ -553,11 +609,17 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
     calculateWidget();
     if( !m_pFText )
         return;
-    if (m_scene->getSelectCount(true) > 1)
+    if (m_scene->selectedCount(true) > 1)
         return;
     setTextPosition();
 }
 
+/**
+ * Check to see if the given ObjectWidget is involved in the message.
+ *
+ * @param w The ObjectWidget to check for.
+ * @return  true - if is contained, false - not contained.
+ */
 bool MessageWidget::contains(ObjectWidget * w)
 {
     if(m_pOw[Uml::A] == w || m_pOw[Uml::B] == w)
@@ -578,6 +640,10 @@ void MessageWidget::slotMenuSelection(QAction* action)
     }
 }
 
+/**
+ * Activates a MessageWidget.  Connects its m_pOw[] pointers
+ * to UMLObjects and also send signals about its FloatingTextWidget.
+ */
 bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
 {
     m_scene->resetPastePoint();
@@ -785,6 +851,12 @@ UMLClassifier * MessageWidget::seqNumAndOp(QString& seqNum, QString& op)
     return c;
 }
 
+/**
+ * Calculates the size of the widget by calling
+ * calculateDimensionsSynchronous(),
+ * calculateDimensionsAsynchronous(), or
+ * calculateDimensionsCreation()
+ */
 void MessageWidget::calculateDimensions()
 {
     if (m_sequenceMessageType == Uml::sequence_message_synchronous) {
@@ -801,18 +873,21 @@ void MessageWidget::calculateDimensions()
         uWarning() << "Unknown message type";
     }
     if (! UMLApp::app()->document()->loading()) {
-        adjustAssocs( getX(), getY() );  // adjust assoc lines
+        adjustAssocs( x(), y() );  // adjust assoc lines
     }
 }
 
+/**
+ * Calculates and sets the size of the widget for a synchronous message.
+ */
 void MessageWidget::calculateDimensionsSynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
-    int w2 = m_pOw[Uml::B]->getWidth() / 2;
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w2 = m_pOw[Uml::B]->width() / 2;
     x1 += w1;
     x2 += w2;
 
@@ -839,14 +914,17 @@ void MessageWidget::calculateDimensionsSynchronous()
     setSize(widgetWidth, widgetHeight);
 }
 
+/**
+ * Calculates and sets the size of the widget for an asynchronous message.
+ */
 void MessageWidget::calculateDimensionsAsynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
-    int w2 = m_pOw[Uml::B]->getWidth() / 2;
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w2 = m_pOw[Uml::B]->width() / 2;
     x1 += w1;
     x2 += w2;
 
@@ -873,14 +951,17 @@ void MessageWidget::calculateDimensionsAsynchronous()
     setSize(widgetWidth, widgetHeight);
 }
 
+/**
+ * Calculates and sets the size of the widget for a creation message.
+ */
 void MessageWidget::calculateDimensionsCreation()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->getX();
-    int x2 = m_pOw[Uml::B]->getX();
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
-    int w2 = m_pOw[Uml::B]->getWidth();
+    int x1 = m_pOw[Uml::A]->x();
+    int x2 = m_pOw[Uml::B]->x();
+    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w2 = m_pOw[Uml::B]->width();
     x1 += w1;
     if (x1 > x2)
         x2 += w2;
@@ -897,17 +978,20 @@ void MessageWidget::calculateDimensionsCreation()
     x += 1;
     widgetWidth -= 2;
     m_nPosX = x;
-    m_nY = m_pOw[Uml::B]->getY() + m_pOw[Uml::B]->getHeight() / 2;
+    m_nY = m_pOw[Uml::B]->y() + m_pOw[Uml::B]->height() / 2;
     setSize(widgetWidth, widgetHeight);
 }
 
+/**
+ * Calculates and sets the size of the widget for a lost message.
+ */
 void MessageWidget::calculateDimensionsLost()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->getX();
+    int x1 = m_pOw[Uml::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
+    int w1 = m_pOw[Uml::A]->width() / 2;
 
     x1 += w1;
 
@@ -925,13 +1009,16 @@ void MessageWidget::calculateDimensionsLost()
     setSize(widgetWidth, widgetHeight);
 }
 
+/**
+ * Calculates and sets the size of the widget for a found message.
+ */
 void MessageWidget::calculateDimensionsFound()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->getX();
+    int x1 = m_pOw[Uml::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->getWidth() / 2;
+    int w1 = m_pOw[Uml::A]->width() / 2;
     x1 += w1;
 
 
@@ -950,6 +1037,9 @@ void MessageWidget::calculateDimensionsFound()
     setSize(widgetWidth, widgetHeight);
 }
 
+/**
+ * Used to cleanup any other widget it may need to delete.
+ */
 void MessageWidget::cleanup()
 {
     if (m_pOw[Uml::A]) {
@@ -968,30 +1058,40 @@ void MessageWidget::cleanup()
     }
 }
 
+/**
+ * Sets the state of whether the widget is selected.
+ *
+ * @param _select   True if the widget is selected.
+ */
 void MessageWidget::setSelected(bool _select)
 {
     UMLWidget::setSelected( _select );
     if( !m_pFText || m_pFText->displayText().isEmpty())
         return;
-    if( m_selected && m_pFText -> getSelected() )
+    if( m_selected && m_pFText->isSelected() )
         return;
-    if( !m_selected && !m_pFText -> getSelected() )
+    if( !m_selected && !m_pFText->isSelected() )
         return;
 
     m_scene -> setSelected( m_pFText, 0 );
     m_pFText -> setSelected( m_selected );
 }
 
+/**
+ * Returns the minimum height this widget should be set at on
+ * a sequence diagrams.  Takes into account the widget positions
+ * it is related to.
+ */
 int MessageWidget::getMinY()
 {
     if (!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
         return 0;
     }
     if (m_sequenceMessageType == Uml::sequence_message_creation) {
-        return m_pOw[Uml::A]->getY() + m_pOw[Uml::A]->getHeight();
+        return m_pOw[Uml::A]->y() + m_pOw[Uml::A]->height();
     }
-    int heightA = m_pOw[Uml::A]->getY() + m_pOw[Uml::A]->getHeight();
-    int heightB = m_pOw[Uml::B]->getY() + m_pOw[Uml::B]->getHeight();
+    int heightA = m_pOw[Uml::A]->y() + m_pOw[Uml::A]->height();
+    int heightB = m_pOw[Uml::B]->y() + m_pOw[Uml::B]->height();
     int height = heightA;
     if( heightA < heightB ) {
         height = heightB;
@@ -999,6 +1099,11 @@ int MessageWidget::getMinY()
     return height;
 }
 
+/**
+ * Returns the maximum height this widget should be set at on
+ * a sequence diagrams.  Takes into account the widget positions
+ * it is related to.
+ */
 int MessageWidget::getMaxY()
 {
     if( !m_pOw[Uml::A] || !m_pOw[Uml::B] ) {
@@ -1035,23 +1140,23 @@ ObjectWidget* MessageWidget::objectWidget(Uml::Role_Type role)
     return m_pOw[role];
 }
 
-void MessageWidget::setxclicked (int xclick)
+/**
+ * Set the xclicked
+ */
+void MessageWidget::setxclicked(int xclick)
 {
     xclicked = xclick;
 }
 
 
-void MessageWidget::setyclicked (int yclick)
+/**
+ * Set the yclicked
+ */
+void MessageWidget::setyclicked(int yclick)
 {
     yclicked = yclick;
 }
 
-// void  MessageWidget::setSize(int width,int height);
-// {
-//
-//     UMLWidget::setSize(width,height);
-// }
-
 /**
  * Saves to the "messagewidget" XMI element.
  */
